@@ -26,6 +26,13 @@ else:
     _prefetch_generator_available = True
 
 
+def _cli_requires():
+    return [
+        'pytorch_lightning>=0.7.1',
+        'opencv-python'
+    ]
+
+
 def is_lightning_available():
     return _lightning_available
 
@@ -43,4 +50,4 @@ if is_lightning_available():
     from ._one_liners import train_self_supervised_model
     from ._one_liners import get_image_features
 
-__version__ = '0.1.5'
+__version__ = '0.1.7'
