@@ -1,10 +1,10 @@
-import os
 import time
 import random
 import requests
 
-SERVER_LOCATION = os.getenvb(b'BORIS_SERVER_LOCATION',
-                             b'https://api.whattolabel.com').decode()
+from boris.api._utils import getenv
+SERVER_LOCATION = getenv('BORIS_SERVER_LOCATION',
+                         'https://api.whattolabel.com')
 
 
 def _post_request(dst_url, data=None, json=None,
@@ -123,11 +123,11 @@ def create_initial_tag(dataset_id: str, token: str):
 
 def get_presigned_upload_url(filename: str,
                              dataset_id: str,
+                             sample_id: str,
                              token: str) -> str:
     """Creates and returns a signed url to upload an image for a specific dataset
 
     Args:
-        filename: Name of file used for database and cloud storage
         dataset_id: Identifier of the dataset
         token: The token for authenticating the request
 
@@ -138,19 +138,20 @@ def get_presigned_upload_url(filename: str,
         RuntimeError if requesting signed url failed
     """
     payload = {
-        'sample': {
-            'fileName': filename,
-        },
+        'fileName': filename,
         'token': token
     }
-    dst_url = f'{SERVER_LOCATION}/users/datasets/{dataset_id}/samples'
-    response = _post_request(dst_url, json=payload)
-    data = response.json()
-    signed_url = data['signedWriteUrl']
+
+    dst_url = f'{SERVER_LOCATION}/users/'
+    dst_url += f'datasets/{dataset_id}/'
+    dst_url += f'samples/{sample_id}/writeurl'
+
+    response = _get_request(dst_url, params=payload)
+    signed_url = response.json()['signedWriteUrl']
     return signed_url
 
 
-def upload_file_with_signed_url(filename: str, url: str) -> bool:
+def upload_file_with_signed_url(file, url: str) -> bool:
     """Upload a file to the cloud storage using a signed URL
 
     Args:
@@ -160,12 +161,37 @@ def upload_file_with_signed_url(filename: str, url: str) -> bool:
     Returns:
         A boolean value indicating successful upload
     """
-    file = open(filename, 'rb')
     response = _put_request(url, data=file)
     file.close()
     return response
 
 
+def upload_sample_with_metadata(filename: str,
+                                thumbname: str,
+                                metadata: str,
+                                dataset_id: str,
+                                token: str):
+    """
+
+    """
+    payload = {
+        'sample': {
+            'fileName': filename,
+            'meta': metadata,
+        },
+        'token': token
+    }
+    if thumbname is not None:
+        payload['sample']['thumbName'] = thumbname
+
+    dst_url = f'{SERVER_LOCATION}/users/'
+    dst_url += f'datasets/{dataset_id}/samples/'
+
+    response = _post_request(dst_url, json=payload)
+    sample_id = response.json()['sampleId']
+    return sample_id
+
+
 def upload_embedding(data: dict) -> bool:
     """Uploads embedding
 
@@ -190,29 +216,33 @@ def upload_embedding(data: dict) -> bool:
     return response
 
 
+def get_tags(dataset_id: str,
+             token: str):
+    payload = {'token': token}
+    dst_url = f'{SERVER_LOCATION}/users/datasets/{dataset_id}/tags/'
+    response = _get_request(dst_url, params=payload)
+    return response.json()
+
+
 def get_samples(dataset_id: str,
                 token: str,
                 tag_name: str = 'initial-tag'):
-    # payload is the same for both requests
-    payload = {
-        'token': token
-    }
 
     # get tag_id
-    dst_url = f'{SERVER_LOCATION}/users/datasets/{dataset_id}/tags/'
-    response = _get_request(dst_url, params=payload)
-    tag_ids = [t['_id'] for t in response.json() if t['name'] == tag_name]
+    tags = get_tags(dataset_id, token)
+    tag_ids = [t['_id'] for t in tags if t['name'] == tag_name]
     if len(tag_ids) == 0:
         msg = f'No tag with name {tag_name} found '
         msg += f'for datset with id {dataset_id}'
         raise RuntimeError(msg)
     elif len(tag_ids) > 1:
-        msg = f'{len(tag_ids)} tags with name {tag_name} founr '
+        msg = f'{len(tag_ids)} tags with name {tag_name} found '
         msg += f'for dataset with id {dataset_id}'
         raise RuntimeError(msg)
     tag_id = tag_ids[0]
 
     # get files in tag
+    payload = {'token': token}
     dst_url = f'{SERVER_LOCATION}/users/datasets/'
     dst_url += f'{dataset_id}/tags/{tag_id}/download'
 
