@@ -1,6 +1,5 @@
 import os
 
-
 import pandas as pd
 
 from itertools import islice
@@ -9,22 +8,32 @@ from typing import List
 from boris.api._communication import create_initial_tag
 from boris.api._communication import get_presigned_upload_url
 from boris.api._communication import upload_file_with_signed_url
+from boris.api._communication import upload_sample_with_metadata
 from boris.api._communication import upload_embedding
 from boris.api._communication import get_samples
+from boris.api._communication import get_tags
+
+from boris.api._utils import get_thumbnail_from_img
+from boris.api._utils import check_image
+from boris.api._utils import PIL_to_bytes
+
 from boris.data import BorisDataset
 from boris.utils import pandas_to_dict
 
+
 import tqdm
 import warnings
 from concurrent.futures import ThreadPoolExecutor
 
-MAXIMUM_DATASET_SIZE = 10_000
+import PIL.Image as Image
+
+MAXIMUM_DATASET_SIZE = 25_000
 
 
 def upload_embeddings_from_csv(path_to_embeddings: str,
                                dataset_id: str,
                                token: str,
-                               max_upload: int = 512):
+                               max_upload: int = 32):
     """Uploads embeddings from a csv file to the cloud solution
 
     Args:
@@ -42,6 +51,11 @@ def upload_embeddings_from_csv(path_to_embeddings: str,
     data['token'] = token
     data['datasetId'] = dataset_id
 
+    tags = get_tags(dataset_id, token)
+    if len(tags) == 0:
+        msg = 'Forbidden upload to dataset with no existing tags.'
+        raise RuntimeError(msg)
+
     def _upload_single_batch(batch, append=False):
         batch['append'] = int(append)
         upload_embedding(batch)
@@ -68,7 +82,8 @@ def upload_images_from_folder(path_to_folder: str,
                               dataset_id: str,
                               token: str,
                               max_workers: int = 8,
-                              max_requests: int = 8):
+                              max_requests: int = 8,
+                              mode: str = 'thumbnails'):
     """Uploads images from a directory to the cloud solution
 
     Args:
@@ -76,6 +91,9 @@ def upload_images_from_folder(path_to_folder: str,
         dataset_id: The unique identifier for the dataset
         token: Token for authentication
 
+    Raises:
+        ValueError if dataset is too large
+        RuntimeError if dataset already has an initial tag
     """
 
     bds = BorisDataset(from_folder=path_to_folder)
@@ -83,29 +101,80 @@ def upload_images_from_folder(path_to_folder: str,
 
     if len(fnames) > MAXIMUM_DATASET_SIZE:
         msg = f'Your dataset has {len(fnames)} samples which'
-        msg += f'is more than the allowed maximum of {MAXIMUM_DATASET_SIZE}'
+        msg += f' is more than the allowed maximum of {MAXIMUM_DATASET_SIZE}'
         raise ValueError(msg)
 
+    tags = get_tags(dataset_id, token)
+    if len(tags) > 0:
+        tag_names = [t['name'] for t in tags]
+        msg = 'Forbidden upload to dataset with existing tags: '
+        msg += f'{tag_names}'
+        raise RuntimeError(msg)
+
     def _upload_single_image(fname):
 
-        success = True
-        # try to get signed url
+        # get PIL image handles, metadata, and check if corrupted
+        metadata, is_corrupted = check_image(
+            os.path.join(path_to_folder, fname), mode=mode
+        )
+
+        # filename is too long, cannot accept this file
+        if not metadata:
+            return False
+
+        # upload sample
+        basename = fname
+        thumbname = None
+        if mode in ['full', 'thumbnails'] and not is_corrupted:
+            thumbname = '.'.join(basename.split('.')[:-1]) + '_thumb.webp'
+
+        sample_upload_success = True
         try:
-            basename = fname
-            signed_url = get_presigned_upload_url(
-                basename, dataset_id, token
+            sample_id = upload_sample_with_metadata(
+                basename, thumbname, metadata, dataset_id, token
             )
         except RuntimeError:
-            success = False
+            sample_upload_success = False
 
-        # try to upload image
-        try:
-            if success:
-                full_fname = os.path.join(path_to_folder, fname)
-                upload_file_with_signed_url(full_fname, signed_url)
-        except RuntimeError:
-            success = False
+        # upload thumbnail
+        thumbnail_upload_success = True
+        if mode == 'thumbnails' and not is_corrupted:
+            try:
+                # try to get signed url for thumbnail
+                signed_url = get_presigned_upload_url(
+                    thumbname, dataset_id, sample_id, token
+                )
+                # try to create thumbnail
+                with Image.open(os.path.join(path_to_folder, fname)) as temp_image:
+                    thumbnail = get_thumbnail_from_img(temp_image)
+                # try to upload thumbnail
+                upload_file_with_signed_url(
+                    PIL_to_bytes(thumbnail, ext='webp', quality=70),
+                    signed_url
+                )
+            except RuntimeError:
+                thumbnail_upload_success = False
 
+        # upload full image
+        image_upload_success = True
+        if mode == 'full' and not is_corrupted:
+            try:
+                # try to get signed url for image
+                signed_url = get_presigned_upload_url(
+                    basename, dataset_id, sample_id, token
+                )
+                # try to upload image
+                with open(os.path.join(path_to_folder, fname), 'rb') as temp_image:
+                    upload_file_with_signed_url(
+                        temp_image,
+                        signed_url
+                    )
+            except RuntimeError:
+                image_upload_success = False
+
+        success = sample_upload_success
+        success = success and thumbnail_upload_success
+        success = success and image_upload_success
         return success
 
     n_batches = len(fnames) // max_requests
