@@ -1,5 +1,5 @@
 import os
-
+import torch
 
 def _prepend_hydra_prefix(path):
     """Hydra creates a working directory depending on the time stamps.
@@ -47,15 +47,21 @@ def _model_zoo(model):
 
     zoo = {
 
+        'resnet-9/simclr/d16/w0.0625':
+        'https://storage.googleapis.com/models_boris/whattolabel-resnet9-simclr-d16-w0.0625-i-ce0d6bd9.pth',
+
         'resnet-9/simclr/d16/w0.125':
         'https://storage.googleapis.com/models_boris/whattolabel-resnet9-simclr-d16-w0.125-i-7269c38d.pth',
 
         'resnet-18/simclr/d16/w1.0':
         'https://storage.googleapis.com/models_boris/whattolabel-resnet18-simclr-d16-w1.0-i-58852cb9.pth',
 
+        'resnet-18/simclr/d32/w1.0':
+        'https://storage.googleapis.com/models_boris/whattolabel-resnet18-simclr-d32-w1.0-i-085d0693.pth',
+
         'resnet-34/simclr/d16/w1.0':
         'https://storage.googleapis.com/models_boris/whattolabel-resnet34-simclr-d16-w1.0-i-6e80d963.pth',
-        
+
     }
 
     key = model['name']
@@ -69,3 +75,25 @@ def _model_zoo(model):
         return '', key
 
 
+def load_state_dict_from_url(url, map_location=None):
+
+    try:
+        state_dict = torch.hub.load_state_dict_from_url(
+            url, map_location=map_location
+        )
+        return state_dict
+    except Exception:
+        print('Not able to load state dict from %s' % (url))
+        print('Retrying with http:// prefix')
+    try:
+        url = url.replace('https', 'http')
+        state_dict = torch.hub.load_state_dict_from_url(
+            url, map_location=map_location
+        )
+        return state_dict
+    except Exception:
+        print('Not able to load state dict from %s' % (url))
+
+    # in this case downloading the pre-trained model was not possible
+    # notify the user and return
+    return {'state_dict': None}
