@@ -8,6 +8,14 @@
 
 """
 
+import boris
+__requires__ = boris._cli_requires()
+if not boris.is_lightning_available():
+    msg = 'Using `boris-magic` requires the following '
+    msg += 'pre-requisites to be installed first: '
+    msg += f'{", ".join(__requires__)}.'
+    raise RuntimeError(msg)
+
 import hydra
 
 from boris.cli.train_cli import _train_cli
