@@ -8,6 +8,14 @@
 
 """
 
+import boris
+__requires__ = boris._cli_requires()
+if not boris.is_lightning_available():
+    msg = 'Using `boris-embed` requires the following '
+    msg += 'pre-requisites to be installed first: '
+    msg += f'{", ".join(__requires__)}.'
+    raise RuntimeError(msg)
+
 import os
 
 import hydra
@@ -19,10 +27,10 @@ from boris.embedding import SelfSupervisedEmbedding
 from boris.models import ResNetSimCLR
 from boris.utils import embeddings_to_pandas
 
-from boris.cli._helpers import _is_url
 from boris.cli._helpers import _model_zoo
 from boris.cli._helpers import fix_input_path
 from boris.cli._helpers import filter_state_dict
+from boris.cli._helpers import load_state_dict_from_url
 
 
 def _embed_cli(cfg, is_cli_call=True):
@@ -92,7 +100,7 @@ def _embed_cli(cfg, is_cli_call=True):
             msg = 'Cannot download checkpoint for key {} '.format(key)
             msg += 'because it does not exist!'
             raise RuntimeError(msg)
-        state_dict = torch.hub.load_state_dict_from_url(
+        state_dict = load_state_dict_from_url(
             checkpoint, map_location=device
         )['state_dict']
     else:
@@ -100,10 +108,12 @@ def _embed_cli(cfg, is_cli_call=True):
         state_dict = torch.load(
             checkpoint, map_location=device
         )['state_dict']
-    state_dict = filter_state_dict(state_dict)
-    model.load_state_dict(state_dict)
-    encoder = SelfSupervisedEmbedding(model, None, None, None)
 
+    if state_dict is not None:
+        state_dict = filter_state_dict(state_dict)
+        model.load_state_dict(state_dict)
+
+    encoder = SelfSupervisedEmbedding(model, None, None, None)
     embeddings, labels, filenames = encoder.embed(dataloader, device=device)
 
     df = embeddings_to_pandas(embeddings, labels, filenames)
