@@ -8,6 +8,14 @@
 
 """
 
+import boris
+__requires__ = boris._cli_requires()
+if not boris.is_lightning_available():
+    msg = 'Using `boris-train` requires the following '
+    msg += 'pre-requisites to be installed first: '
+    msg += f'{", ".join(__requires__)}.'
+    raise RuntimeError(msg)
+
 import hydra
 import warnings
 
@@ -21,6 +29,7 @@ from boris.cli._helpers import _is_url
 from boris.cli._helpers import _model_zoo
 from boris.cli._helpers import fix_input_path
 from boris.cli._helpers import filter_state_dict
+from boris.cli._helpers import load_state_dict_from_url
 
 import torch
 
@@ -76,8 +85,8 @@ def _train_cli(cfg, is_cli_call=True):
     model = ResNetSimCLR(**cfg['model'])
     checkpoint = cfg['checkpoint']
     if cfg['pre_trained'] and not checkpoint:
-        # if checkpoint wasn't specified explicitly and pre_trained is True
-        # try to load the checkpoint from the model zoo
+        # if checkpoint wasn't specified explicitly and pre_trained is True
+        # try to load the checkpoint from the model zoo
         checkpoint, key = _model_zoo(cfg['model'])
         if not checkpoint:
             msg = 'Cannot download checkpoint for key {} '.format(key)
@@ -93,16 +102,17 @@ def _train_cli(cfg, is_cli_call=True):
         # checkpoint saver and load the model from the "filtered" state dict
         # this approach is compatible with pytorch_lightning 0.7.1 - 0.8.4 (latest)
         if _is_url(checkpoint):
-            state_dict = torch.hub.load_state_dict_from_url(
+            state_dict = load_state_dict_from_url(
                 checkpoint, map_location=device
             )['state_dict']
         else:
             state_dict = torch.load(
                 checkpoint, map_location=device
             )['state_dict']
-        state_dict = filter_state_dict(state_dict)
-        model.load_state_dict(state_dict)
-        
+        if state_dict is not None:
+            state_dict = filter_state_dict(state_dict)
+            model.load_state_dict(state_dict)
+
     criterion = NTXentLoss(**cfg['criterion'])
     optimizer = torch.optim.SGD(model.parameters(), **cfg['optimizer'])
 
